==> com.liferay.layout.content.page.editor.web-1.0.20.jar: META-INF/resources/js/reducers/mapping.es.js <==
"use strict";

Liferay.Loader.define("layout-content-page-editor-web@1.0.20/js/reducers/mapping.es", ['module', 'exports', 'require', '../actions/actions.es', '../utils/FragmentsEditorUpdateUtils.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.addMappingAssetEntry = addMappingAssetEntry;

  var _actions = require("../actions/actions.es");

  var _FragmentsEditorUpdateUtils = require("../utils/FragmentsEditorUpdateUtils.es");

  function _toConsumableArray(arr) {
    return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread();
  }

  function _nonIterableSpread() {
    throw new TypeError("Invalid attempt to spread non-iterable instance");
  }

  function _iterableToArray(iter) {
    if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter);
  }

  function _arrayWithoutHoles(arr) {
    if (Array.isArray(arr)) {
      for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) {
        arr2[i] = arr[i];
      }return arr2;
    }
  }

  /**
   * @param {object} state
   * @param {object} action
   * @param {string} action.classNameId
   * @param {string} action.classPK
   * @param {string} action.title
   * @param {string} action.type
   */
  function addMappingAssetEntry(state, action) {
    var nextState = state;

    if (action.type === _actions.ADD_MAPPED_ASSET_ENTRY) {
      var hasAssetEntry = nextState.mappedAssetEntries.some(function (assetEntry) {
        return assetEntry.classNameId === action.classNameId && assetEntry.classPK === action.classPK;
      });

      if (!hasAssetEntry) {
        nextState = (0, _FragmentsEditorUpdateUtils.setIn)(nextState, ['mappedAssetEntries'], [].concat(_toConsumableArray(nextState.mappedAssetEntries), [action]));
      }
    }

    return nextState;
  }
  //# sourceMappingURL=mapping.es.js.map
});
//# sourceMappingURL=mapping.es.js.map

==> com.liferay.layout.content.page.editor.web-1.0.52.jar: META-INF/resources/js/reducers/mapping.es.js <==
Liferay.Loader.define("layout-content-page-editor-web@1.0.52/js/reducers/mapping.es", ['module', 'exports', 'require', '../utils/FragmentsEditorUpdateUtils.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.addMappingAssetEntry = addMappingAssetEntry;

  var _FragmentsEditorUpdateUtils = require("../utils/FragmentsEditorUpdateUtils.es");

  function _toConsumableArray(arr) {
    return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread();
  }

  function _nonIterableSpread() {
    throw new TypeError("Invalid attempt to spread non-iterable instance");
  }

  function _iterableToArray(iter) {
    if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter);
  }

  function _arrayWithoutHoles(arr) {
    if (Array.isArray(arr)) {
      for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) {
        arr2[i] = arr[i];
      }return arr2;
    }
  }

  /**
   * @param {object} state
   * @param {object} action
   * @param {string} action.classNameId
   * @param {string} action.classPK
   * @param {string} action.title
   * @param {string} action.type
   */
  function addMappingAssetEntry(state, action) {
    var nextState = state;
    var hasAssetEntry = nextState.mappedAssetEntries.some(function (assetEntry) {
      return assetEntry.classNameId === action.classNameId && assetEntry.classPK === action.classPK;
    });

    if (!hasAssetEntry) {
      nextState = (0, _FragmentsEditorUpdateUtils.setIn)(nextState, ['mappedAssetEntries'], [].concat(_toConsumableArray(nextState.mappedAssetEntries), [action]));
    }

    return nextState;
  }
  //# sourceMappingURL=mapping.es.js.map
});
//# sourceMappingURL=mapping.es.js.map
